mypackage_da_dec21
==================

.. image:: https://img.shields.io/pypi/v/mypackage_da_dec21.svg
    :target: https://pypi.python.org/pypi/mypackage_da_dec21
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/dilip-albert-datascientist/mypackage_da_dec21.png
   :target: https://travis-ci.org/dilip-albert-datascientist/mypackage_da_dec21
   :alt: Latest Travis CI build status

An example package

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`mypackage_da_dec21` was written by `Dilip Albert <dilip_albert_datascientist@outlook.com>`_.
